package org.apache.poi.xssf;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.junit.Before;
import org.junit.Test;

public class TestXSSFCloneSheet {

    private static final String OTHER_SHEET_NAME = "Another";
    private static final String VALID_SHEET_NAME = "Sheet01";
    private XSSFWorkbook wb;

    @Before
    public void setUp() {
        wb = new XSSFWorkbook();
        wb.createSheet(VALID_SHEET_NAME);  
    }
    
    
    @Test
    public void testCloneSheetIntValid() {
        wb.cloneSheet(0);
        assertEquals(2, wb.getNumberOfSheets());
        try {
            wb.cloneSheet(2);
            fail("ShouldFail");
        } catch (IllegalArgumentException e) {
            
        }
    }

    @Test
    public void testCloneSheetIntInvalid() {
        try {
            wb.cloneSheet(1);
            fail("Should Fail");
        } catch (IllegalArgumentException e) {
            
        }
        assertEquals(1, wb.getNumberOfSheets());
    }

    @Test
    public void testCloneSheetIntStringValidName() {
        XSSFSheet cloned = wb.cloneSheet(0, OTHER_SHEET_NAME);
        assertEquals(OTHER_SHEET_NAME, cloned.getSheetName());
        assertEquals(2, wb.getNumberOfSheets());
    }
    
    @Test
    public void testCloneSheetIntStringInvalidName() {
        try {
            wb.cloneSheet(0, VALID_SHEET_NAME);
            fail("Should fail");
        } catch (IllegalArgumentException e) {
            
        }
        assertEquals(1, wb.getNumberOfSheets());
    }

}
